@@ -167,10 +167,10 @@ class Assistant(QWidget):
         input_layer = self._get_active_layer()
         if not input_layer:
             warn("Please select a layer first")
-            return False
+            return
 
         # make a new widget
-        gui = make_gui_for_category(category, self.seach_field.text(), self._viewer)
+        gui = make_gui_for_category(category, self.seach_field.text(), self._viewer,autocall=category.auto_call)
         # prevent auto-call when adding to the viewer, to avoid double calls
         # do this here rather than widget creation for the sake of
         # non-Assistant-based widgets.
